@@ -2,7 +2,6 @@
  *   Copyright (C) 2005 by Joshua Keel <joshuakeel@gmail.com>              *
  *             (C) 2007 by Jeremy Whiting <jpwhiting@kde.org>              *
  *                                                                         *
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -20,28 +19,27 @@
  ***************************************************************************/
 
 #include "vocabsettings.h"
-#include "vocabedit.h"
 
-#include <kstandarddirs.h>
-#include <kconfigdialog.h>
-#include <qfileinfo.h>
+#include <KConfigDialog>
+#include <KNS3/DownloadDialog>
 
-#include <knewstuff3/downloaddialog.h>
-#include <knewstuff3/knewstuffbutton.h>
 #include <sharedkvtmlfiles.h>
-#include <keduvocdocument.h>
-#include <kanagramsettings.h>
 
+#include <QIcon>
+#include <QFileInfo>
 #include <QtCore/QPointer>
 
-VocabSettings::VocabSettings(QWidget *parent) : QWidget(parent), m_parent(NULL)
+#include "kanagramsettings.h"
+#include "vocabedit.h"
+
+VocabSettings::VocabSettings(QWidget *parent)
+    : QWidget(parent)
 {
     setupUi(this);
-    m_parent = (KConfigDialog*)parent;
 
     connect(lviewVocab, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(slotSelectionChanged(QTreeWidgetItem*)));
 
-    btnDownloadNew->setIcon(KIcon("get-hot-new-stuff"));
+    btnDownloadNew->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
 
     refreshView();
 }
@@ -50,28 +48,34 @@ VocabSettings::~VocabSettings()
 {
 }
 
-void VocabSettings::refreshView()
+void VocabSettings::loadView()
 {
     lviewVocab->clear();
 
     SharedKvtmlFiles::sortDownloadedFiles();
-    m_fileList = SharedKvtmlFiles::fileNames(KanagramSettings::dataLanguage());
-    m_titleList = SharedKvtmlFiles::titles(KanagramSettings::dataLanguage());
-    m_commentList = SharedKvtmlFiles::comments(KanagramSettings::dataLanguage());
+    QString language = KanagramSettings::dataLanguage();
+    m_fileList = SharedKvtmlFiles::fileNames(language);
+    m_titleList = SharedKvtmlFiles::titles(language);
+    m_commentList = SharedKvtmlFiles::comments(language);
 
-    for(int i = 0; i < m_fileList.size(); i++)
+    for (int i = 0; i < m_fileList.size(); i++)
     {
         QTreeWidgetItem *item = new QTreeWidgetItem(lviewVocab, 0);
         item->setText( 0, m_titleList[i] );
         item->setText( 1, m_commentList[i] );
         m_itemMap[item] = i;
     }
-    m_parent->enableButtonApply(true);
+}
+
+void VocabSettings::refreshView()
+{
+    loadView();
+    emit widgetModified();
 }
 
 void VocabSettings::on_btnEdit_clicked()
 {
-    if(lviewVocab->currentItem())
+    if (lviewVocab->currentItem())
     {
         int index = m_itemMap[lviewVocab->currentItem()];
         VocabEdit *vocabEdit = new VocabEdit(this, m_fileList[index]);
@@ -89,20 +93,18 @@ void VocabSettings::on_btnCreateNew_clicked()
 
 void VocabSettings::on_btnDownloadNew_clicked()
 {
-    QPointer<KNS3::DownloadDialog> hotNewStuffdialog = new KNS3::DownloadDialog( "kanagram.knsrc" );
-    hotNewStuffdialog->exec();
-    if ( hotNewStuffdialog->changedEntries().size() > 0 ){
+    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog( "kanagram.knsrc" );
+    dialog->exec();
+    if ( dialog->changedEntries().size() > 0 ){
         refreshView();
     }
 
-    delete hotNewStuffdialog;
+    delete dialog;
 }
 
 void VocabSettings::slotSelectionChanged(QTreeWidgetItem *item)
 {
-    int index = m_itemMap[item];
+    int index = m_itemMap.value(item);
     bool writeable = QFileInfo(m_fileList[index]).isWritable();
     btnEdit->setEnabled(writeable);
 }
-
-#include "vocabsettings.moc"
